@@ -41,7 +41,7 @@ class PyGBQDataError(PyGBQError):
 
     def __init__(self, row, error_info):
         super(PyGBQDataError, self).__init__(
-            msg=f"Row {row} caused the following errors:\n{error_info}"
+            msg=f"Error {error_info} has been cause by the row:\n{row}"
         )
 
 
@@ -235,7 +235,13 @@ JOIN (SELECT {backtick_fields}, COUNT(*)
                 raise E
 
     def replace(self, data_batch):
-        self.client.delete_table(table=self.table_id)  # doesn't work without delete
+        try:
+            self.client.get_table(self.table_id)
+            table_exists = True
+        except google.cloud.exceptions.NotFound:
+            table_exists = False
+        if table_exists:
+            self.client.delete_table(table=self.table_id)  # doesn't work without delete
         table = bigquery.Table(self.table_id, schema=self.schema.schema_api)
         table = self.client.create_table(table=table, exists_ok=True)
         self.errors = self.client.insert_rows(table, data_batch)
@@ -429,14 +435,14 @@ class Client:
                 logging.exception(message)
         return message
 
-    def callback(self, callback, arguments):
-        query_job = self.client.query(callback.format(**arguments))
+    def query(self, query, arguments):
+        query_job = self.client.query(query.format(**arguments))
         try:
             query_job.result()
-            message = 'Callback executed correctly'
+            message = 'Query executed correctly'
         except Exception as E:
-            message = f"Your query '{callback}' is incorrect"
-            logging.exception(f"Your query '{callback}' is incorrect")
+            message = f"Your query '{query}' is incorrect"
+            logging.exception(f"Your query '{query}' is incorrect")
         return message
 
     def file_name_for_save(self, table_id, parameters, extension: str = ""):
@@ -482,7 +488,7 @@ class Client:
     #         table: str = None,
     #         how: Union[str, List[str]] = None,
     #         schema: Union[str, List[dict]] = None,
-    #         callback: str = None,
+    #         query: str = None,
     #         test: str = None
     # ):
     #     if not table:
@@ -520,8 +526,8 @@ class Client:
     #             raise PyGBQError(f"Returned {type(data)}. Need either list or df.")
     #         if test:
     #             self.test(test=test, arguments=kwargs)
-    #         if callback:
-    #             self.callback(callback, kwargs)
+    #         if query:
+    #             self.query(query, kwargs)
     #         return results
     #
     #     return inner
